@@ -233,7 +233,7 @@ void parseFreeLast(void) {
   sFree(&_bufw2);
 }
 
-void parseFree(int last){
+void parseFree(int last) {
   sFree(&sb);
   sFree(&sbDt);
   sFree(&sbt);
@@ -272,6 +272,11 @@ void parseFree(int last){
   }
 }
 
+SEXP _rxode2parse_parseFreeSexp(SEXP last) {
+  parseFree(INTEGER(last)[0]);
+  return R_NilValue;
+}
+
 void reset(void) {
   // Reset sb/sbt string buffers
   parseFree(0);
